import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { CloudWatchLogsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CloudWatchLogsClient";
import { DeleteIndexPolicyRequest, DeleteIndexPolicyResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteIndexPolicyCommand}.
 */
export interface DeleteIndexPolicyCommandInput extends DeleteIndexPolicyRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteIndexPolicyCommand}.
 */
export interface DeleteIndexPolicyCommandOutput extends DeleteIndexPolicyResponse, __MetadataBearer {
}
declare const DeleteIndexPolicyCommand_base: {
    new (input: DeleteIndexPolicyCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteIndexPolicyCommandInput, DeleteIndexPolicyCommandOutput, CloudWatchLogsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: DeleteIndexPolicyCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteIndexPolicyCommandInput, DeleteIndexPolicyCommandOutput, CloudWatchLogsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Deletes a log-group level field index policy that was applied to a single log group. The indexing of the log events that happened before
 *     you delete the policy will still be used for as many as 30 days to improve CloudWatch Logs Insights queries.</p>
 *          <p>You can't use this operation to delete an account-level index policy. Instead, use
 *       <a href="https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteAccountPolicy.html">DeletAccountPolicy</a>.</p>
 *          <p>If you delete a log-group level field index policy and there is an account-level field index policy, in a few minutes the log group begins using that account-wide policy to index new
 *       incoming log events. </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudWatchLogsClient, DeleteIndexPolicyCommand } from "@aws-sdk/client-cloudwatch-logs"; // ES Modules import
 * // const { CloudWatchLogsClient, DeleteIndexPolicyCommand } = require("@aws-sdk/client-cloudwatch-logs"); // CommonJS import
 * const client = new CloudWatchLogsClient(config);
 * const input = { // DeleteIndexPolicyRequest
 *   logGroupIdentifier: "STRING_VALUE", // required
 * };
 * const command = new DeleteIndexPolicyCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeleteIndexPolicyCommandInput - {@link DeleteIndexPolicyCommandInput}
 * @returns {@link DeleteIndexPolicyCommandOutput}
 * @see {@link DeleteIndexPolicyCommandInput} for command's `input` shape.
 * @see {@link DeleteIndexPolicyCommandOutput} for command's `response` shape.
 * @see {@link CloudWatchLogsClientResolvedConfig | config} for CloudWatchLogsClient's `config` shape.
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>A parameter is specified incorrectly.</p>
 *
 * @throws {@link LimitExceededException} (client fault)
 *  <p>You have reached the maximum number of resources that can be created.</p>
 *
 * @throws {@link OperationAbortedException} (client fault)
 *  <p>Multiple concurrent requests to update the same resource were in conflict.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource does not exist.</p>
 *
 * @throws {@link ServiceUnavailableException} (server fault)
 *  <p>The service cannot complete the request.</p>
 *
 * @throws {@link CloudWatchLogsServiceException}
 * <p>Base exception class for all service exceptions from CloudWatchLogs service.</p>
 *
 *
 * @public
 */
export declare class DeleteIndexPolicyCommand extends DeleteIndexPolicyCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteIndexPolicyRequest;
            output: {};
        };
        sdk: {
            input: DeleteIndexPolicyCommandInput;
            output: DeleteIndexPolicyCommandOutput;
        };
    };
}
