import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { CloudWatchLogsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CloudWatchLogsClient";
import { DescribeConfigurationTemplatesRequest, DescribeConfigurationTemplatesResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DescribeConfigurationTemplatesCommand}.
 */
export interface DescribeConfigurationTemplatesCommandInput extends DescribeConfigurationTemplatesRequest {
}
/**
 * @public
 *
 * The output of {@link DescribeConfigurationTemplatesCommand}.
 */
export interface DescribeConfigurationTemplatesCommandOutput extends DescribeConfigurationTemplatesResponse, __MetadataBearer {
}
declare const DescribeConfigurationTemplatesCommand_base: {
    new (input: DescribeConfigurationTemplatesCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeConfigurationTemplatesCommandInput, DescribeConfigurationTemplatesCommandOutput, CloudWatchLogsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [DescribeConfigurationTemplatesCommandInput]): import("@smithy/smithy-client").CommandImpl<DescribeConfigurationTemplatesCommandInput, DescribeConfigurationTemplatesCommandOutput, CloudWatchLogsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Use this operation to return the valid and default values that are used when creating delivery sources, delivery destinations, and deliveries.
 *       For more information about deliveries, see <a href="https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CreateDelivery.html">CreateDelivery</a>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudWatchLogsClient, DescribeConfigurationTemplatesCommand } from "@aws-sdk/client-cloudwatch-logs"; // ES Modules import
 * // const { CloudWatchLogsClient, DescribeConfigurationTemplatesCommand } = require("@aws-sdk/client-cloudwatch-logs"); // CommonJS import
 * const client = new CloudWatchLogsClient(config);
 * const input = { // DescribeConfigurationTemplatesRequest
 *   service: "STRING_VALUE",
 *   logTypes: [ // LogTypes
 *     "STRING_VALUE",
 *   ],
 *   resourceTypes: [ // ResourceTypes
 *     "STRING_VALUE",
 *   ],
 *   deliveryDestinationTypes: [ // DeliveryDestinationTypes
 *     "S3" || "CWL" || "FH",
 *   ],
 *   nextToken: "STRING_VALUE",
 *   limit: Number("int"),
 * };
 * const command = new DescribeConfigurationTemplatesCommand(input);
 * const response = await client.send(command);
 * // { // DescribeConfigurationTemplatesResponse
 * //   configurationTemplates: [ // ConfigurationTemplates
 * //     { // ConfigurationTemplate
 * //       service: "STRING_VALUE",
 * //       logType: "STRING_VALUE",
 * //       resourceType: "STRING_VALUE",
 * //       deliveryDestinationType: "S3" || "CWL" || "FH",
 * //       defaultDeliveryConfigValues: { // ConfigurationTemplateDeliveryConfigValues
 * //         recordFields: [ // RecordFields
 * //           "STRING_VALUE",
 * //         ],
 * //         fieldDelimiter: "STRING_VALUE",
 * //         s3DeliveryConfiguration: { // S3DeliveryConfiguration
 * //           suffixPath: "STRING_VALUE",
 * //           enableHiveCompatiblePath: true || false,
 * //         },
 * //       },
 * //       allowedFields: [ // AllowedFields
 * //         { // RecordField
 * //           name: "STRING_VALUE",
 * //           mandatory: true || false,
 * //         },
 * //       ],
 * //       allowedOutputFormats: [ // OutputFormats
 * //         "json" || "plain" || "w3c" || "raw" || "parquet",
 * //       ],
 * //       allowedActionForAllowVendedLogsDeliveryForResource: "STRING_VALUE",
 * //       allowedFieldDelimiters: [ // AllowedFieldDelimiters
 * //         "STRING_VALUE",
 * //       ],
 * //       allowedSuffixPathFields: [
 * //         "STRING_VALUE",
 * //       ],
 * //     },
 * //   ],
 * //   nextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param DescribeConfigurationTemplatesCommandInput - {@link DescribeConfigurationTemplatesCommandInput}
 * @returns {@link DescribeConfigurationTemplatesCommandOutput}
 * @see {@link DescribeConfigurationTemplatesCommandInput} for command's `input` shape.
 * @see {@link DescribeConfigurationTemplatesCommandOutput} for command's `response` shape.
 * @see {@link CloudWatchLogsClientResolvedConfig | config} for CloudWatchLogsClient's `config` shape.
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource does not exist.</p>
 *
 * @throws {@link ServiceUnavailableException} (server fault)
 *  <p>The service cannot complete the request.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The request was throttled because of quota limits.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>One of the parameters for the request is not valid.</p>
 *
 * @throws {@link CloudWatchLogsServiceException}
 * <p>Base exception class for all service exceptions from CloudWatchLogs service.</p>
 *
 *
 * @public
 */
export declare class DescribeConfigurationTemplatesCommand extends DescribeConfigurationTemplatesCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DescribeConfigurationTemplatesRequest;
            output: DescribeConfigurationTemplatesResponse;
        };
        sdk: {
            input: DescribeConfigurationTemplatesCommandInput;
            output: DescribeConfigurationTemplatesCommandOutput;
        };
    };
}
